###DOmake.met.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
## Modif Jun99 mlvl62 - Modified version of ins_met
## Modif Jan00 revelle - Correct spelling of Meteorological
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.monthly.met.page.plot   <date.ext>"
   echo " (produces profile ps file named metfile.<date.ext>.ps)"
   exit
endif

echo DOmake.monthly.met.page.plot $1 - started
cd $DIRUWDATA/MET

set month = $1 

#
/bin/rm -f monthly.data
touch monthly.data
set file_cnt = 0
#
foreach i ( ??$month??.dat* )
	echo Processing met file $i
	if ( -e $i.Z ) then
		zcat $i >> monthly.data
		@ file_cnt++
	else
		if ( -e $i) then
			@ file_cnt++
		zcat $i >> monthly.data
#		i	cat $i >> monthly.data
		endif
	endif
end

if ( $file_cnt == 0) then
	echo No file found, exiting
	exit
endif
set IFN = monthly.data
#
# Change these Lower/Upper ranges as necessary:

set AIRTEMP_RANGE = 15/40
set AIRTEMP_TIC = "a2g2f1:air temp (C.):"

set BARO_RANGE = 15/40
set BARO_TIC = "a10g5f5:Barometric pres (mm):"

set HUMI_RANGE = 15/40
set HUMI_TIC = "a10g5f5:Humidity (%):"

set PRIC_RANGE = 15/40
set PRIC_TIC = "a2g1f1:precipitation:"

set SHOR_RANGE = 15/40
set SHOR_TIC = "a100g200f50:Short Wave:"

set LONG_RANGE = 15/40
set LONG_TIC = "a100g200f10:Long Wave:"

# Don't change these:
set HR_RANGE       = 0./$file_cnt.       ; set HR_TIC       = "2g1::"
echo $HR_RANGE

# test for the data file to exist
if !( -e $IFN) then
	echo "DOmake.monthly.met.page.plot: No data file: $IFN"
	exit
endif

# test if any data in file to process
grep ^METDTA $IFN > /dev/null
if ( $status == 1) then
	echo no met data found
#	/bin/rm -f $IFN
	exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = Weekly.MET.$1.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.1
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.5
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "Meteorological Data $CRUISE month $month"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

/usr/local/bin/ins/ins_met < $IFN > all_data

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`


###################### start 1st panel ######################################
#
# First temp sensor

$BINDIR/met_weekly_ins_data.awk field=6 scale=2 all_data > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$AIRTEMP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################

$BINDIR/met_weekly_ins_data.awk field=5 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$BARO_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 3nd panel ######################################

$BINDIR/met_weekly_ins_data.awk field=7 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$HUMI_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 4nd panel ######################################

$BINDIR/met_weekly_ins_data.awk field=9 scale=2 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$PRIC_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 5nd panel ######################################

$BINDIR/met_weekly_ins_data.awk field=11 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SHOR_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 6nd panel ######################################

$BINDIR/met_weekly_ins_data.awk field=10 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$LONG_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
lp $OFN

#
# remove work files
#
/bin/rm -f all_data range 2col
#
/bin/rm -f $IFN
#end
