###DOmake.met.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
## Modif Jun99 mlvl62 - Modified version of ins_met
## Modif Jan00 revelle - Correct spelling of Meteorological
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.weekly.met.page.plot   <date.ext>"
   echo " (produces profile ps file named metfile.<date.ext>.ps)"
   exit
endif

echo DOmake.weekly.trans.page.plot $1 - started
cd $DIRUWDATA/TRANS

set DATE = $1

#
# Get a list of last 7 days of data
set tem0 = $1
set IFN7 = `$BINDIR/trans_filename $tem0`cor
set  tem1 = `$BINDIR/yesterday $tem0`
set IFN6 = `$BINDIR/trans_filename $tem1`cor
set  tem2 = `$BINDIR/yesterday $tem1`
set IFN5 = `$BINDIR/trans_filename $tem2`cor
set  tem3 = `$BINDIR/yesterday $tem2`
set IFN4 = `$BINDIR/trans_filename $tem3`cor
set  tem4 = `$BINDIR/yesterday $tem3`
set IFN3 = `$BINDIR/trans_filename $tem4`cor
set  tem5 = `$BINDIR/yesterday $tem4`
set IFN2 = `$BINDIR/trans_filename $tem5`cor
set  tem6 = `$BINDIR/yesterday $tem5`
set IFN1 = `$BINDIR/trans_filename $tem6`cor

#echo $IFN1 $IFN2 $IFN3 $IFN4 $IFN5 $IFN6 $IFN7
/bin/rm -f weekly.data
touch weekly.data
set file_cnt = 0
foreach i ( $IFN1 $IFN2 $IFN3 $IFN4 $IFN5 $IFN6 $IFN7 )
	echo Processing met file $i
	if ( -e $i.Z ) then
		zcat $i >> weekly.data
		@ file_cnt++
	else
		if ( -e $i) then
			@ file_cnt++
			cat $i >> weekly.data
		endif
	endif
end
if ( $file_cnt == 0) then
	echo No file found, exiting
	exit
endif
set IFN = weekly.data
#
# Change these Lower/Upper ranges as necessary:

set AIRTEMP_RANGE = 15/40
set AIRTEMP_TIC = "a2g2f1:air temp (C.):"

set BARO_RANGE = 15/40
set BARO_TIC = "a10g5f5:Barometric pres (mm):"

set HUMI_RANGE = 15/40
set HUMI_TIC = "a10g5f5:Humidity (%):"

set PRIC_RANGE = 15/40
set PRIC_TIC = "a10g5f5:precipitation:"

set SHOR_RANGE = 15/40
set SHOR_TIC = "a100g200f50:Short Wave:"

set LONG_RANGE = 15/40
set LONG_TIC = "a100g200f10:Long Wave:"

# Don't change these:
set HR_RANGE       = 0./$file_cnt.       ; set HR_TIC       = "2g1::"
echo $HR_RANGE

# test for the data file to exist
if !( -e $IFN) then
	echo "DOmake.weekly.met.page.plot: No data file: $IFN"
	exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = Weekly.MET.$1.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.1
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.5
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "Meteorological Data $CRUISE week ending $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`


###################### start 1st panel ######################################
#
# First temp sensor

$BINDIR/trans_extract_weekly.awk field=AT scale=1 $IFN > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$AIRTEMP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################

$BINDIR/trans_extract_weekly.awk field=BP scale=5 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$BARO_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 3nd panel ######################################

$BINDIR/trans_extract_weekly.awk field=RH scale=10 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$HUMI_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 4nd panel ######################################

$BINDIR/trans_extract_weekly.awk field=PM scale=10 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$PRIC_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 5nd panel ######################################

$BINDIR/trans_extract_weekly.awk field=SW scale=10 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SHOR_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 6nd panel ######################################

$BINDIR/trans_extract_weekly.awk field=LW scale=50 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$LONG_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
lp $OFN

#
# remove work files
#
/bin/rm -f all_data range 2col
#
/bin/rm -f $IFN
#end
